@@ -18,6 +18,6 @@ class Sigmoid(Layer):
         self.dy_dx = self.result * (1 - self.result)
         return self.dy_dx * dL_dy
 
-class sigmoid(Layer):
+class sigmoid(Sigmoid):
     def __init__(self):
         pass
\ No newline at end of file
